# bitcart-sdk
[![PyPI version](https://badge.fury.io/py/bitcart.svg)](https://badge.fury.io/py/bitcart)

This is a client library(wrapper) around bitcart daemon. It is used to simplify common commands. New coins may be added soon.
